@@ -9,11 +9,13 @@ bcRes <- 10 # (10 arcmin)
 envar <- c('bio05', 'bio06', 'bio13', 'bio14')
 
 ### run function
-arcmin10 <- envs_worldclim(bcRes, bcSel = envar)
+arcmin10 <- try(envs_worldclim(bcRes, bcSel = envar), silent = TRUE)
 
 
 ### test if the error messages appear when they are supposed to
 test_that("error checks", {
+  # Skip if cannot download
+  skip_if(class(arcmin10) == "try-error")
   # the user has not selected a raster resolution
   expect_error(envs_worldclim(bcRes = '', bcSel = envar, doBrick = FALSE),
                'Select a raster resolution.')
@@ -23,6 +25,8 @@ test_that("error checks", {
 test_that("output type checks", {
   # skip on CRAN
   skip_on_cran()
+  # Skip if cannot download
+  skip_if(class(arcmin10) == "try-error")
   # the output is a RasterBrick
   expect_is(arcmin10, "RasterStack")
   # the number of layer is the same as specified in the selected variables list
